# Generated by Django 4.2.23 on 2025-11-05 16:17

from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):
    dependencies = [
        ('edu_rdm_integration_upload_data_stage', '0004_fix_fk_constraints'),
    ]

    operations = [
        migrations.AddField(
            model_name='rdmexportingdatasubstageuploaderclientlog',
            name='temp_entry_id',
            field=models.BigIntegerField(null=True, verbose_name='Лог запроса и ответа'),
        ),
        migrations.AddField(
            model_name='rdmuploadstatusrequestlog',
            name='temp_entry_id',
            field=models.BigIntegerField(null=True, verbose_name='Cвязь запроса статуса с запросом в витрину'),
        ),
    ]
