# Generated by Django 4.2.23 on 2025-11-07 18:23

from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):
    dependencies = [
        (
            'edu_rdm_integration_upload_data_stage',
            '0006_alter_rdmexportingdatasubstageuploaderclientlog_entry_and_more',
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rdmexportingdatasubstageuploaderclientlog',
            name='entry_id',
        ),
        migrations.RemoveField(
            model_name='rdmuploadstatusrequestlog',
            name='entry_id',
        ),
    ]
