# Generated by Django 4.2.23 on 2025-11-05 16:17

from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):
    dependencies = [
        ('edu_rdm_integration_collect_data_stage', '0006_fix_fk_constraints'),
    ]

    operations = [
        migrations.AddField(
            model_name='rdmcollectingdatacommandprogress',
            name='temp_task_id',
            field=models.UUIDField(blank=True, null=True, verbose_name='Асинхронная задача'),
        ),
        migrations.AddField(
            model_name='rdmcollectingdatastage',
            name='temp_manager_id',
            field=models.UUIDField(blank=True, null=True, verbose_name='Менеджер ранера Функции'),
        ),
        migrations.AddField(
            model_name='rdmcollectingdatasubstage',
            name='temp_function_id',
            field=models.UUIDField(null=True, verbose_name='Функция'),
        ),
    ]
