# Generated by Django 4.2.23 on 2025-11-07 18:23

from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):
    dependencies = [
        ('edu_rdm_integration_collect_data_stage', '0008_alter_rdmcollectingdatacommandprogress_task_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rdmcollectingdatacommandprogress',
            name='task_id',
        ),
        migrations.RemoveField(
            model_name='rdmcollectingdatastage',
            name='manager_id',
        ),
        migrations.RemoveField(
            model_name='rdmcollectingdatasubstage',
            name='function_id',
        ),
    ]
