# Generated by Django 4.2.23 on 2025-11-10 11:53

from django.db import (
    migrations,
)


class Migration(migrations.Migration):
    dependencies = [
        ('edu_rdm_integration_collect_data_stage', '0009_remove_rdmcollectingdatacommandprogress_task_id_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='rdmcollectingdatacommandprogress',
            old_name='temp_task_id',
            new_name='task_id',
        ),
        migrations.RenameField(
            model_name='rdmcollectingdatastage',
            old_name='temp_manager_id',
            new_name='manager_id',
        ),
        migrations.RenameField(
            model_name='rdmcollectingdatasubstage',
            old_name='temp_function_id',
            new_name='function_id',
        ),
    ]
